@@ -1,13 +1,12 @@
-from six import python_2_unicode_compatible
-
-from quickbooks.objects.detailline import DetailLine, ItemBasedExpenseLine, AccountBasedExpenseLine
+from quickbooks.objects.detailline import DetailLine, ItemBasedExpenseLine, AccountBasedExpenseLine, \
+    TDSLine
 from .base import Ref, Address, QuickbooksManagedObject, LinkedTxnMixin, \
     QuickbooksTransactionEntity, CustomField, LinkedTxn
 from .tax import TxnTaxDetail
+from ..mixins import DeleteMixin, SendMixin
 
 
-@python_2_unicode_compatible
-class PurchaseOrder(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
+class PurchaseOrder(DeleteMixin, QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin, SendMixin):
     """
     QBO definition: The PurchaseOrder entity is a non-posting transaction representing a request to purchase
     goods or services from a third party.
@@ -35,6 +34,7 @@ class PurchaseOrder(QuickbooksManagedObject, QuickbooksTransactionEntity, Linked
     detail_dict = {
         "ItemBasedExpenseLineDetail": ItemBasedExpenseLine,
         "AccountBasedExpenseLineDetail": AccountBasedExpenseLine,
+        "TDSLineDetail": TDSLine,
     }
 
     qbo_object_name = "PurchaseOrder"
@@ -49,6 +49,8 @@ class PurchaseOrder(QuickbooksManagedObject, QuickbooksTransactionEntity, Linked
         self.DueDate = None
         self.ExchangeRate = 1
         self.GlobalTaxCalculation = "TaxExcluded"
+        self.Memo = None
+        self.ShipMethodRef = None
 
         self.TxnTaxDetail = None
         self.VendorAddr = None
